summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJordan Henderson <jhenderson@hdfgroup.org>2017-03-30 18:29:11 (GMT)
committerJordan Henderson <jhenderson@hdfgroup.org>2017-03-30 18:29:11 (GMT)
commita513e5bf84282a62e725f6de5b8eb229ea36e99d (patch)
tree22dc3e7f225611aa0ff4d219f16e69f0b6a7d085
parent6bc14164e6707ab201234e02d8eadf719a0caa05 (diff)
downloadhdf5-a513e5bf84282a62e725f6de5b8eb229ea36e99d.zip
hdf5-a513e5bf84282a62e725f6de5b8eb229ea36e99d.tar.gz
hdf5-a513e5bf84282a62e725f6de5b8eb229ea36e99d.tar.bz2
Add comments to H5D_filtered_collective_io_info_t data structure
Correct comment and error message about retrieving the threshold for performing either Linked-chunk or Multi-chunk I/O
-rw-r--r--src/H5Dmpio.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/H5Dmpio.c b/src/H5Dmpio.c
index af5d44b..583abfd 100644
--- a/src/H5Dmpio.c
+++ b/src/H5Dmpio.c
@@ -95,16 +95,16 @@ typedef struct H5D_chunk_addr_info_t {
H5D_chunk_info_t chunk_info;
} H5D_chunk_addr_info_t;
-/* Information about a chunk when performing collective filtered IO */
+/* Information about a single chunk when performing collective filtered IO */
typedef struct H5D_filtered_collective_io_info_t {
- H5D_chunk_info_t chunk_info;
- H5F_block_t old_chunk;
- H5F_block_t new_chunk;
- hbool_t full_overwrite;
- size_t io_size;
- size_t num_writers;
- int owner;
- void *buf;
+ H5D_chunk_info_t chunk_info; /* Info about this chunk, such as chunk index and file and memory dataspace */
+ H5F_block_t old_chunk; /* The address in the file and size of this chunk before being filtered */
+ H5F_block_t new_chunk; /* The address in the file and size of this chunk after being filtered */
+ hbool_t full_overwrite; /* Whether or not this chunk is being fully overwritten */
+ size_t io_size; /* Size of the I/O to this chunk */
+ size_t num_writers; /* Total number of processes writing to this chunk */
+ int owner; /* Process which will be writing to this chunk */
+ void *buf; /* Chunk data to be written to file/that has been read from file*/
} H5D_filtered_collective_io_info_t;
/********************/
@@ -738,9 +738,9 @@ H5D__chunk_collective_io(H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
if((mpi_size = H5F_mpi_get_size(io_info->dset->oloc.file)) < 0)
HGOTO_ERROR(H5E_IO, H5E_MPI, FAIL, "unable to obtain mpi size")
/* Get the chunk optimization option */
if(H5P_get(dx_plist, H5D_XFER_MPIO_CHUNK_OPT_NUM_NAME, &one_link_chunk_io_threshold) < 0)
- HGOTO_ERROR(H5E_IO, H5E_CANTGET, FAIL, "couldn't get chunk optimization option")
+ HGOTO_ERROR(H5E_IO, H5E_CANTGET, FAIL, "couldn't get chunk optimization option threshold value")
/* step 1: choose an IO option */
/* If the average number of chunk per process is greater than a threshold, we will do one link chunked IO. */
@@ -738,9 +738,9 @@ H5D__chunk_collective_io(H5D_io_info_t *io_info, const H5D_type_info_t *type_inf
if((mpi_size = H5F_mpi_get_size(io_info->dset->oloc.file)) < 0)
HGOTO_ERROR(H5E_IO, H5E_MPI, FAIL, "unable to obtain mpi size")
- /* Get the chunk optimization option */
+ /* Get the chunk optimization option threshold */
if(H5P_get(dx_plist, H5D_XFER_MPIO_CHUNK_OPT_NUM_NAME, &one_link_chunk_io_threshold) < 0)